summaryrefslogtreecommitdiff
path: root/lib/tdb2/test/run-15-append.c
diff options
context:
space:
mode:
authorRusty Russell <rusty@rustcorp.com.au>2011-09-14 08:13:26 +0930
committerRusty Russell <rusty@rustcorp.com.au>2011-09-14 08:13:26 +0930
commit01b2214a1893db5071addf1fdf17e9ac06ed63a0 (patch)
treee3fe69fccee166bef42e4dbad2bc2f1655824fdb /lib/tdb2/test/run-15-append.c
parentef70f5dd35974115a85850d04b0f4b64e511659f (diff)
downloadsamba-01b2214a1893db5071addf1fdf17e9ac06ed63a0.tar.gz
samba-01b2214a1893db5071addf1fdf17e9ac06ed63a0.tar.bz2
samba-01b2214a1893db5071addf1fdf17e9ac06ed63a0.zip
tdb2: test: try (almost) all tests with TDB_VERSION1 flag.
There are some minor changes required, in particular: 1) Make sure lockcheck understands tdb1 allrecord lock upgrades. 2) Handle tdb1 sequence number jumps: various operations increment the sequence number twice, especually tdb_append. 3) Don't test fail on unlock, since it gets triggered with traversal on the tdb1 backend (we didn't actually ever test this case for tdb2). 4) Move clear_if_first to offset 4, to match tdb1. Signed-off-by: Rusty Russell <rusty@rustcorp.com.au> (Imported from CCAN commit 818ed29730b030ce79855fc35c212b51adff3180)
Diffstat (limited to 'lib/tdb2/test/run-15-append.c')
-rw-r--r--lib/tdb2/test/run-15-append.c35
1 files changed, 30 insertions, 5 deletions
diff --git a/lib/tdb2/test/run-15-append.c b/lib/tdb2/test/run-15-append.c
index ac37960a6f..46a77ff976 100644
--- a/lib/tdb2/test/run-15-append.c
+++ b/lib/tdb2/test/run-15-append.c
@@ -12,6 +12,12 @@ static tdb_off_t tdb_offset(struct tdb_context *tdb, struct tdb_data key)
struct tdb_used_record rec;
struct hash_info h;
+ if (tdb_get_flags(tdb) & TDB_VERSION1) {
+ struct tdb1_record rec;
+ return tdb1_find(tdb, key, tdb_hash(tdb, key.dptr, key.dsize),
+ &rec);
+ }
+
off = find_and_lock(tdb, key, F_RDLCK, &h, &rec, NULL);
if (TDB_OFF_IS_ERR(off))
return 0;
@@ -27,7 +33,12 @@ int main(int argc, char *argv[])
tdb_off_t oldoff = 0, newoff;
int flags[] = { TDB_INTERNAL, TDB_DEFAULT, TDB_NOMMAP,
TDB_INTERNAL|TDB_CONVERT, TDB_CONVERT,
- TDB_NOMMAP|TDB_CONVERT };
+ TDB_NOMMAP|TDB_CONVERT,
+ TDB_INTERNAL|TDB_VERSION1, TDB_VERSION1,
+ TDB_NOMMAP|TDB_VERSION1,
+ TDB_INTERNAL|TDB_CONVERT|TDB_VERSION1,
+ TDB_CONVERT|TDB_VERSION1,
+ TDB_NOMMAP|TDB_CONVERT|TDB_VERSION1 };
struct tdb_data key = tdb_mkdata("key", 3);
struct tdb_data data;
@@ -64,8 +75,15 @@ int main(int argc, char *argv[])
}
ok1(!tdb->file || (tdb->file->allrecord_lock.count == 0
&& tdb->file->num_lockrecs == 0));
- /* We should increase by 50% each time... */
- ok(moves <= ilog64(j / SIZE_STEP)*2, "Moved %u times", moves);
+ if (flags[i] & TDB_VERSION1) {
+ /* TDB1 simply over-size by 25%. */
+ ok(moves <= ilog64(j / SIZE_STEP)*4,
+ "Moved %u times", moves);
+ } else {
+ /* We should increase by 50% each time... */
+ ok(moves <= ilog64(j / SIZE_STEP)*2,
+ "Moved %u times", moves);
+ }
tdb_close(tdb);
}
@@ -96,8 +114,15 @@ int main(int argc, char *argv[])
}
ok1(!tdb->file || (tdb->file->allrecord_lock.count == 0
&& tdb->file->num_lockrecs == 0));
- /* We should increase by 50% each time... */
- ok(moves <= ilog64(j / SIZE_STEP)*2, "Moved %u times", moves);
+ if (flags[i] & TDB_VERSION1) {
+ /* TDB1 simply over-size by 25%. */
+ ok(moves <= ilog64(j / SIZE_STEP)*4,
+ "Moved %u times", moves);
+ } else {
+ /* We should increase by 50% each time... */
+ ok(moves <= ilog64(j / SIZE_STEP)*2,
+ "Moved %u times", moves);
+ }
tdb_close(tdb);
}